angular.module('starter.controllers', [])

.controller('AppCtrl', function($scope, $state, $window, $timeout, $ionicScrollDelegate, $ionicTabsDelegate, $ionicModal, UserService, PopupService) {
  $scope.userData = UserService.get() || {username:false};
  $scope.loginData = {};

  $ionicModal.fromTemplateUrl('templates/login.html', {
    scope: $scope,
    focusFirstInput: true
  }).then(function(modal) {
    $scope.modal = modal;
  });

  $scope.closeLogin = function() {
    $scope.modal.hide();
    $scope.loginData = {};
  };

  $scope.login = function() {
    $scope.modal.show();
  };
  $scope.logout = function () {
    var confirmPopup = PopupService.confirm('注销', '确定要退出吗？');
    confirmPopup.then(function(res){
      if(res) {
        UserService.signOut();
        $scope.userData = {};
        $timeout(function(){
          $state.go('tab.inn', {}, {reload: true});
        });
        $scope.$apply();
      }
    });
  };
  $scope.doLogin = function(fallback) {
    UserService.signIn($scope.loginData.username, $scope.loginData.password,
      function(user) {
        $scope.userData = UserService.get();
        $scope.$apply();
        $timeout(function() {
          $scope.closeLogin();
        }, 100);
        $timeout(function() {
          $state.go($state.current, {}, {reload: true});
        }, 500);
      },
      function(user,error) {
        PopupService.alert('网络连接错误', error.message);
      }
    );
  };
  $scope.goRegister = function() {
    $scope.closeLogin();
    $state.go('register', {}, {});
  };
  $scope.goResetPassword = function () {
    $scope.closeLogin();
    $state.go('resetpassword', {}, {});
  };

  $scope.toggleSignInOut = function () {
    if($scope.userData.username) {
      $scope.logout();
    } else {
      $scope.login();
    }
  };

  var bottomPosition = parseInt($window.innerHeight * 0.53);
  //if($window.innerHeight<580) {
  //  bottomPosition = 300;
  //}
  var lastPosition = [0,0,0,0],
    toPosition = [bottomPosition,bottomPosition,bottomPosition,bottomPosition];
  var nextPosition = function(curPosition) {
    if(curPosition==0) {
      return bottomPosition;
    } else {
      return 0;
    }
  };
  $scope.checkPosition = function () {
    lastPosition[$ionicTabsDelegate.selectedIndex()] = $ionicScrollDelegate.getScrollPosition().top;
  };
  $scope.fixPosition = function () {
    var index = $ionicTabsDelegate.selectedIndex();
    if(Math.abs(lastPosition[index] - Math.abs($ionicScrollDelegate.getScrollPosition().top))>35) {
      $ionicScrollDelegate.scrollTo(0,toPosition[index],true);
      toPosition[index] = nextPosition(toPosition[index]);
    } else {
      $ionicScrollDelegate.scrollTo(0,nextPosition(toPosition[index]),true);
    }
  };

})

.controller('RegisterCtrl', function($scope, $state, $ionicModal, $ionicHistory, UserService, PopupService) {
  $scope.register = {};

  $ionicModal.fromTemplateUrl('templates/agreement.html', {
    scope: $scope
  }).then(function(modal) {
    $scope.modal = modal;
  });

  $scope.showAgreement = function() {
    $scope.modal.show();
  };

  $scope.closeAgreement = function() {
    $scope.modal.hide();
  };

  $scope.closeRegister = function() {
    if($ionicHistory.backView()) {
      $ionicHistory.goBack()
    } else {
      $state.go('tab.inn');
    }
  };
  $scope.doRegister = function(fallback) {
    // Require Validation
    var a = $scope.register;
    if(!a.agreement) {
      PopupService.alert(null, '必须阅读并接受《箱子客服务协议》才可进行下一步操作');
      return false;
    }
    // Submit register
    UserService.signUp({
      username: a.username,
      password: a.password,
      email: a.email,
      mobilePhoneNumber: a.username,
      name: a.name
    },
    function(user) {
      console.log(user);
      var alertPopup = PopupService.alert('注册成功', '恭喜您成为我们的会员');
      alertPopup.then(function(res){
        $state.go('tab.inn', {}, {reload: true});
      });
    },
    function(user,error) {
      PopupService.alert('网络连接错误', error.message);
    });
    return false;
  };


  })


.controller('ResetPasswordCtrl', function($scope, $state, $ionicModal, $ionicHistory, UserService, PopupService) {
    $scope.resetData = {};
    $scope.codeSent = false;
    $scope.closeResetPassword = function() {
      if($ionicHistory.backView()) {
        $ionicHistory.goBack()
      } else {
        $state.go('tab.inn');
      }
    };
    $scope.sendCode = function () {
      var a = $scope.resetData;
      AV.User.requestPasswordResetBySmsCode(a.mobilePhoneNumber, {
        success: function() {
          $scope.codeSent = true;
          $scope.$apply();
        },
        error: function(error) {
          // Show the error message somewhere
          PopupService.alert("网络连接错误", error.code + " " + error.message);
        }
      });
    };
    $scope.doResetPassword = function () {
      var a = $scope.resetData;
      AV.User.resetPasswordBySmsCode(a.code, a.password, {
        success: function() {
          // Password reset request was sent successfully
          PopupService.alert(null, '密码已变更。请重新登录');
        },
        error: function(error) {
          // Show the error message somewhere
          PopupService.alert("网络连接错误", error.code + " " + error.message);
        }
      });
    };

})

.controller('CustomerServiceCtrl', function($scope) {

})
.controller('BoxInnCtrl', function($scope) {

})
.controller('BoxInnRemoteCtrl', function($scope, $stateParams, PopupService) {
  $scope.targets = [];
  var ControlHead = AV.Object.extend("ControlHead");
  var head = new ControlHead();
  head.id = $stateParams.headId;
  var ControlDevice = AV.Object.extend("ControlDevice");
  var query = new AV.Query(ControlDevice);
  query.equalTo("headId", head);
  query.find({
    success:function(results) {
      $scope.$apply(function(){
        $scope.targets = JSON.parse(JSON.stringify(results));
      });
    }
  });

  $scope.sendJobQueue = function ( deviceId, jobId, deviceName, jobName ) {
    var ControlDevice = AV.Object.extend("ControlDevice");
    var device = new ControlDevice();
    device.id = deviceId;
    var ControlJobQueue = AV.Object.extend("ControlJobQueue");
    var queue = new ControlJobQueue();
    queue.set("deviceId", device);
    queue.set("status", 'PENDING');
    queue.set("value", jobId + '');
    queue.save(null, {
      success: function(queue) {
        //PopupService.alert('成功', 'New object created with objectId: ' + queue.id);
        //PopupService.alert('成功', '正在向' + deviceName + '发送' + jobName + '信号');
        //console.log(arguments);
      },
      error: function(queue, error) {
        PopupService.alert('网络连接错误', error.code + " " + error.message);
        //console.log(arguments);
      }
    });
  };
})
.controller('BoxInnCheckInCtrl', function($scope, $state, PopupService) {
  $scope.authInfo = {
    roomNumber:null,
    name:null
  };

  $scope.doCheckIn = function () {
    var HotelRoom = AV.Object.extend("HotelRoom");
    console.log($scope.authInfo.roomNumber);
    var query = new AV.Query(HotelRoom);
    query.equalTo("roomNumber", $scope.authInfo.roomNumber + '');
    query.first({
      success: function(roomObject) {
        if(!roomObject) {
          PopupService.alert('信息有误','没有对应信息');
          return;
        }
        var now = new Date();
        var HotelCheckin = AV.Object.extend("HotelCheckin");
        var query = new AV.Query(HotelCheckin);
        query.equalTo("name", $scope.authInfo.name + '');
        query.equalTo("roomId", roomObject);
        query.lessThanOrEqualTo("checkIn", now);
        query.greaterThanOrEqualTo("checkOut", now);
        query.first({
          success: function(object) {
            if(object) {
              $state.go('tab.inn-remote', {headId:roomObject.attributes.controlHeadId.id});
            } else {
              PopupService.alert('信息有误','没有对应信息');
            }
          },
          error: function(error) {
            PopupService.alert('网络连接错误', error.code + " " + error.message);
            console.log(arguments);
          }
        });
      },
      error: function(error) {
        PopupService.alert('网络连接错误', error.code + " " + error.message);
        console.log(arguments);
      }
    });
  };

})
.controller('BoxInnAboutCtrl', function($scope) {

})
.controller('BoxCoffeeCtrl', function($scope) {
})
.controller('BoxCoffeeAboutCtrl', function($scope) {

})
.controller('BoxCoffeeIndexCtrl', function($scope, CoffeeIndexes) {
    $scope.coffees = CoffeeIndexes.all();
    var CafeMenu = AV.Object.extend("CafeMenu");
    var query = new AV.Query(CafeMenu);
    query.ascending("itemPriority");
    query.find({
      success:function(results) {
        $scope.$apply(function(){
          CoffeeIndexes.setArray(JSON.parse(JSON.stringify(results)));
          $scope.coffees = CoffeeIndexes.all();
          console.log($scope.coffees);
        });
      }
    });
})
.controller('BoxCoffeeDetailCtrl', function($scope, $stateParams, CoffeeIndexes) {
    $scope.item = CoffeeIndexes.get($stateParams.objectId);
})
.controller('BoxOfficeCtrl', function($scope) {
})
.controller('BoxOfficeAboutCtrl', function($scope) {
});
